/* --COPYRIGHT--,BSD
 * Copyright (C) 2014 Texas Instruments Incorporated - http://www.ti.com/
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  ISR.c - All INT service functions
 *
 ******************************************************************************/

#include "global.h"
#include "ISR.h"
#include "init.h"
#include "motor.h"
#include "key.h"

#pragma vector=TIMER0_A0_VECTOR
__interrupt void PwmPower(void)
{
	TAR = PWMPOWER_FREQ;
}

// Sampling FG to get the speed of the fan
#pragma vector=PORT1_VECTOR
__interrupt void GetFG(void)
{
	preSpeedCounter = curSpeedCounter;
	curSpeedCounter = TA1R;
	speedCounter = curSpeedCounter + overflowCounter*65532 - preSpeedCounter;
	overflowCounter = 0;
	P1IFG &= ~BIT6;   // IFG cleared
}

#pragma vector=TIMER1_A0_VECTOR
__interrupt void StepperState(void)
{
	TA1CCR0 += STEPPER_SPEED; // update CCRO
	stepperSpeedCounter++;
	if(stepperSpeedCounter == (STEPPER_SPEED_DIV>>(MICRO_STEPPING_MODE)))
	{
		stepperSpeedCounter = 0;
		// throttle moving control state
		switch(throttleState)
		{
		case THROTTLE_STATE_ORG:  // throttle back to the closed state
			stepperDir = STEPPER_DIR_CCW; // select closing direction
			StepperLogic();
			if (throttleSteps >= TOTAL_STEPS_CLOSE) // till full closed
			{
				throttleSteps = 0;
				throttleState = 4;
				StopStepper();
			}
			break;
		case THROTTLE_STATE_STOP: // DRV8848 outputs off
			throttleSteps = 0;
			StopStepper();
			break;
		case THROTTLE_STATE_OPEN: // running in the opening direction
			stepperDir = STEPPER_DIR_CW;
			StepperLogic();
			if (throttleSteps >= TOTAL_STEPS_OPEN)
			{
				throttleSteps = 0;
				throttleState = 3;
			}
			break;
		case THROTTLE_STATE_CLOSE: // running in the closing direction
			stepperDir = STEPPER_DIR_CCW;
			StepperLogic();
			if (throttleSteps >= TOTAL_STEPS_CLOSE)
			{
				throttleSteps = 0;
				throttleState = 2;
			}
			break;
		case THROTTLE_STATE_IDLE: // do nothing
			break;
		default:
			break;
		}
	}
}


#pragma vector=TIMER1_A1_VECTOR
__interrupt void FanState(void)
{
	_DINT();
	switch( TA1IV )
	  {
	  case  2: // CCR1
		  TA1CCR1 += SPEED_LOOP_TIME;
		  speedControlFlag = SPEED_CONTROL_ON;

		  break;
	  case  4: // CCR2
		  TA1CCR2 += KEY_DEAL_RATE;
		  // fan operation state
		  switch(stateFan)
		  {
			case STATE_FAN_STOP: // stop PWM output
				TACCTL1 &= ~(BIT7 + BIT6 + BIT5);
				TACCTL2 &= ~(BIT7 + BIT6 + BIT5);
				rampingTime = 0;
				P2OUT &= ~BIT7;
				break;
			case STATE_FAN_POWER_RAMP: // VM ramp up control
				rampingTime++;
				rampingPWM = rampingTime;
				if (rampingPWM < commandADC)
				{
					TA0CCR1 = rampingPWM;
					TA0CCR2 = rampingPWM;
				}
				else if (rampingTime >= commandADC)
				{
					TA0CCR1 = commandADC;
					TA0CCR2 = commandADC;
					rampingTime = 0;
					stateFan = STATE_FAN_RUN;
				}
				TACCTL1 |= OUTMOD_7;
				TACCTL2 |= OUTMOD_7;
				P2OUT |= BIT7;
				break;
			case STATE_FAN_RUN: // normal close loop running
				TA0CCR1 = speedControlOutPWM;
				TA0CCR2 = speedControlOutPWM;
				TACCTL1 |= OUTMOD_7;
				TACCTL2 |= OUTMOD_7;
				P2OUT &= ~BIT7;
				break;
			default:
				break;
		  }
		  KeyDeal(); // insert key dealing function
		  break;
	  case 10: // CCR0
		  overflowCounter++; // for FG calculation
		  break;
	  }
	_EINT();
}
