/* --COPYRIGHT--,BSD
 * Copyright (C) 2014 Texas Instruments Incorporated - http://www.ti.com/
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  init.c - MSP430G2553 initializing functions
 *
 ******************************************************************************/
#include <msp430G2553.h>
#include "init.h"
#include "global.h"

void Initailizing()
{
	WDTCTL = WDTPW | WDTHOLD;		// Stop watchdog timer
	// Set Main Clk 16M
    if (CALBC1_16MHZ==0xFF)			// If calibration constant erased
    {
      while(1);                     // do not load, trap CPU!!
    }
    DCOCTL = 0;                     // Select lowest DCOx and MODx settings
    BCSCTL1 = CALBC1_16MHZ;         // Set range
    DCOCTL = CALDCO_16MHZ;          // Set DCO step + modulation*/

    // Set GPIO OUTPUT for AINx and BINx of DRV8848
	P2DIR |= BIT1 + BIT2;
	P2OUT |= BIT1 + BIT2;
	P3DIR |= BIT2 + BIT3;
	P3OUT |= BIT2 + BIT3;

	// Set GPIO INPUT for keys S1 and S2
	P1DIR &= ~(BIT2 + BIT3);
	P1REN |= BIT2 + BIT3;    		// Enable internal pull resistor
	P1OUT |= BIT2 + BIT3;			// Pull up

	// Set GPIO OUTPUT for the STATUS LED
	P2DIR |= BIT7;
	P2SEL &= ~BIT7;					// Select GPIO for P2.7, default XOUT
	P2OUT &= ~BIT7;

	// Set P3.5 P3.6 as TA0.1 and TA0.2 for PWM outputs to DRV8812
	P3DIR |= BIT5 + BIT6;
	P3SEL |= BIT5 + BIT6;

	// Set P1.6 GPIO ISR to catch the FG falling edge
	P1DIR &= BIT6;
	P1REN |= BIT6;
	P1OUT |= BIT6;
	P1IE  |= BIT6;
	P1IES |= BIT6;
	P1IFG &= ~BIT6;

	// Set TimerA0 for PWM generator to DRV8812
	TACCR0 = PWMPOWER_FREQ;		// Set PWM frequency
								// 16M/PWMPOWER_FREQ = ~32k
	TACCTL1 |= OUTMOD_7;  		// Output mode reset/set
	TACCTL2 |= OUTMOD_7;  		// Output mode reset/set
	TACTL |= TASSEL_2 + MC_1; 	// SMCLK and Up mode;

	// Set TimerA1 CCR0 for the stepper indexer speed
	TA1CCR0 = STEPPER_SPEED;
	// Set TimerA1 CCR1 for the fan speed close loop sampling rate
	TA1CCR1 = SPEED_LOOP_TIME;
	// Set TimerA1 CCR2 for the key scan, fan state
	TA1CCR2 = KEY_DEAL_RATE;
	TA1CCTL0 |= CCIE;        	// Enable CCR0 ISR
	TA1CCTL1 |= CCIE;  			// Enable CCR1 ISR
	TA1CCTL2 |= CCIE;     		// Enable CCR2 ISR
	TA1CTL |= TASSEL_2 + MC_2 + TAIE; // Continual mode

	// Set ADC10
	// Sampled from AVDD to AVSS
	ADC10CTL0 = SREF_0 + ADC10SHT_2 + REFON + ADC10ON;

	_EINT(); // Enable all ISR

	// Set micro stepping mode
	microSteppingMode = MICRO_STEPPING_MODE;
}
