/* --COPYRIGHT--,BSD
 * Copyright (C) 2014 Texas Instruments Incorporated - http://www.ti.com/
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/

/*******************************************************************************
 *
 *  init.h - Definition file for initializing functions
 *
 ******************************************************************************/

#ifndef _INIT_H_
#define _INIT_H_

#include <msp430G2553.h>

#define MAIN_CLK 			(16000000)	// 16M CLK
// defines for PWM_Power of DRV8812
#define PWMPOWER_FREQ 		(500)  		// Change here for PWM frequency
// defines for IO bit operation
#define PWM1_HIGH 			(P3OUT |= BIT6)
#define PWM1_LOW 			(P3OUT &= BIT6)
#define PWM2_HIGH 			(P3OUT |= BIT5)
#define PWM2_LOW 			(P3OUT &= BIT5)

// defines for Throttler_Stepper control of DRV8848
#define STEPPER_SPEED 		(1000) // first level div
#define STEPPER_SPEED_DIV   (50)   // second level div to 80Hz stepper speed
#define MICRO_STEPPING_FULL (0)
#define MICRO_STEPPING_HALF (1)
#define MICRO_STEPPING_MODE (MICRO_STEPPING_HALF)
#define STEPPER_DIR_CW 		(0)  	// open the throttle
#define STEPPER_DIR_CCW 	(1) 	// close the throttle
#define STEPPER_INDEX_0 	(0)
#define STEPPER_INDEX_45 	(1)
#define STEPPER_INDEX_90 	(2)
#define STEPPER_INDEX_135 	(3)
#define STEPPER_INDEX_180 	(4)
#define STEPPER_INDEX_225 	(5)
#define STEPPER_INDEX_270 	(6)
#define STEPPER_INDEX_315 	(7)
//defines for IO bit operation
#define AIN1_LOW  		(P2OUT &= ~BIT1)
#define AIN1_HIGH 		(P2OUT |=  BIT1)
#define AIN2_LOW  		(P2OUT &= ~BIT2)
#define AIN2_HIGH 		(P2OUT |=  BIT2)
#define BIN1_LOW  		(P3OUT &= ~BIT3)
#define BIN1_HIGH 		(P3OUT |=  BIT3)
#define BIN2_LOW  		(P3OUT &= ~BIT2)
#define BIN2_HIGH 		(P3OUT |=  BIT2)
// 460 STEPs for the full range motion at HALF stepping mode
#define TOTAL_STEPS 		(460<<(2+MICRO_STEPPING_MODE))
#define TOTAL_STEPS_CLOSE 	(TOTAL_STEPS + 100)
#define TOTAL_STEPS_OPEN 	(TOTAL_STEPS - 100)
#define THROTTLE_STATE_ORG 		(0) // back to closed ORG
#define THROTTLE_STATE_STOP		(1) // stop state
#define THROTTLE_STATE_OPEN 	(2) // open
#define THROTTLE_STATE_CLOSE	(3) // close
#define THROTTLE_STATE_IDLE		(4) // idle

// defines for close loop speed control of DRV10983
#define KEY_DEAL_RATE 			(60000) // 60000/16M ~3.75ms
// SPEED_LOOP_TIME also affects the Gain of the close loop
// Normally the speed loop sampling is about 1ms to 5ms
#define SPEED_LOOP_TIME 		(20000) // 1.25ms
#define SPEED_CONTROL_ON 		(1)
#define SPEED_CONTROL_DONE 		(0)
// flag of fan state
#define STATE_FAN_STOP 			(0)
#define STATE_FAN_POWER_RAMP 	(1)
#define STATE_FAN_RUN 			(2)
// For DRV10983 PWM_MIN should keep VM > DRV10983 UVLO
// For DRV10975 PWM_MIN can be set lower to achieve lower speed
#define PWM_MIN 				(120)
#define PWM_MAX 				(500) // 500-> 100%
#define SPEED_COMMAND_MIN 		(130<<2) // 130Hz
#define SPEED_COMMAND_MAX 		(160<<2) // 160Hz

extern void Initailizing();

#endif /* _INIT_H_ */
